#aws glue crawler
resource "aws_glue_crawler" "glue_crawler" {
  
  name          = var.glue_crawler_name
  description   = var.glue_crawler_description
  database_name = var.aws_glue_catalog_database_name
  role          = var.glue_crawler_role_arn
  schedule      = var.schedule

  #s3 target
  dynamic "s3_target" {
    for_each = var.s3_target_enabled ? ["true"] : []
    content {
      path = var.s3_target_path
    }
  }

  #dynamodb target
  dynamic "dynamodb_target" {
    for_each = var.dynamodb_target_enabled ? ["true"] : []
    content {
      path = var.dynamodb_target_path
    }
  }

  #jdbc target
  dynamic "jdbc_target" {
    for_each = var.jdbc_target_enabled ? ["true"] : []
    content {
      connection_name = aws_glue_connection.glue_connection[0].name
      path = var.jdbc_target_path
    }
  }

  #catalog target
  dynamic "catalog_target" {
    for_each = var.catalog_target_enabled ? ["true"] : []
    content {
      database_name = var.catalog_target_database_name
      tables        = var.catalog_target_tables
    } 
  }

  #mongodb target
  dynamic "mongodb_target" {
    for_each = var.mongodb_target_enabled ? ["true"] : []
    content {
      connection_name = var.mongodb_target_connection_name
      path            = var.mongodb_target_path
    }
  }

  schema_change_policy {
    delete_behavior = "LOG"
  }

  configuration = <<EOF
  {
    "Version":1.0,
    "Grouping": {
      "TableGroupingPolicy": "CombineCompatibleSchemas"
    },
    "CrawlerOutput": {
      "Partitions": {"AddOrUpdateBehavior": "InheritFromTable" },
      "Tables": {"AddOrUpdateBehavior": "MergeNewColumns" }
    }
  }
  EOF

  tags = var.tags
}