locals {
    glue_crawler_role_name = element(split("/", var.glue_crawler_role_arn),1)
}

resource "aws_iam_policy" "glue-crawler-access-policy" {
  name        = "${var.iam_policy_prefix}-access-policy"
  path        = "/"
  description = "Policy used by the crawler with permission to access your data store."

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Action": [
        "glue:GetCrawler",
        "glue:GetCrawlers",
        "glue:StopCrawler",
        "glue:UpdateCrawler",
        "glue:CreateCrawler",
        "glue:UpdateCrawlerSchedule",
        "glue:BatchGetCrawlers",
        "glue:StartCrawler",
        "glue:StartCrawlerSchedule",
        "glue:StopCrawlerSchedule",
        "glue:ListCrawlers",
        "glue:GetCrawlerMetrics"
      ],
      "Resource": ["${aws_glue_crawler.glue_crawler.arn}"]
    },
    {
      "Effect": "Allow",
      "Action": [
        "glue:GetConnection"
      ],
      "Resource": ["arn:aws:glue:*:*:catalog", "arn:aws:glue:*:*:connection/*"]
    },
    {
      "Effect": "Allow",
      "Action": [
        "cloudwatch:PutMetricData"
       ],
       "Resource": ["*"]
    },
    {
      "Effect": "Allow",
      "Action": [
        "logs:CreateLogGroup",
        "logs:CreateLogStream",
        "logs:PutLogEvents"
      ],
      "Resource": ["arn:aws:logs:*:*:/aws-glue/*"]
    }
  ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }
  tags = var.tags
}

resource "aws_iam_policy_attachment" "glue-crawler-policy-attachment" {
  name       = "${var.iam_policy_prefix}-glue-crawler-policy-attach"
  roles      = [local.glue_crawler_role_name]
  policy_arn = aws_iam_policy.glue-crawler-access-policy.arn

  depends_on = [
    aws_iam_policy.glue-crawler-access-policy
  ]
}