variable "glue_crawler_name" {
  type        = string
  description = "Name of the crawler."
  validation {
    condition     = length(var.glue_crawler_name) > 1
    error_message = "The Name of the crawler must be provided."
  }
}

variable "glue_crawler_description" {
  type        = string
  description = "Description of the crawler."
}

variable "aws_glue_catalog_database_name" {
  type        = string
  description = "Glue database where results are written."
  validation {
    condition     = length(var.aws_glue_catalog_database_name) > 1
    error_message = "Glue database where results are written must be provided."
  }
}

variable "glue_crawler_role_arn" {
  type        = string
  description = "ARN of an IAM role, used by the crawler to access other resources."
  validation {
    condition     = length(var.glue_crawler_role_arn) > 1
    error_message = "ARN of an IAM role, used by the crawler to access other resources must be provided."
  }
}

variable "s3_target_enabled" {
  type    = bool
  default = false
}

variable "dynamodb_target_enabled" {
  type    = bool
  default = false
}

variable "jdbc_target_enabled" {
  type    = bool
  default = false
}

variable "catalog_target_enabled" {
  type    = bool
  default = false
}

variable "mongodb_target_enabled" {
  type    = bool
  default = false
}

variable "s3_target_path" {
  type = string
  description = "The path to the Amazon S3 target."
  default = ""
}

variable "dynamodb_target_path" {
  type = string
  description = "The name of the DynamoDB table to crawl."
  default = ""
}

variable "jdbc_target_connection_name" {
  type = string
  description = "The name of the connection to use to connect to the JDBC target."
  default = ""
}

variable "jdbc_target_path" {
  type = string
  description = "The path of the JDBC target."
  default = ""
}

variable "catalog_target_database_name" {
  type = string
  description = "The name of the Glue database to be synchronized."
  default = ""
}

variable "catalog_target_tables" {
  type = list(string)
  description = "A list of catalog tables to be synchronized."
  default = []
}

variable "mongodb_target_connection_name" {
  type = string
  description = "The name of the connection to use to connect to the Amazon DocumentDB or MongoDB target."
  default = ""
}

variable "mongodb_target_path" {
  type = string
  description = "The path of the Amazon DocumentDB or MongoDB target (database/collection)."
  default = ""
}

variable "tags" {
  type        = map(string)
  description = "Standard Tags for aws glue crawler"
  default     = {}
}

variable "iam_policy_prefix" {
  type = string
}

variable "schedule" {
  type = string
}
  
# aws glue connection
variable "jdbc_url" {
  type        = string      
  description = "JDBC url for the glue connection"
  default = ""
}

variable "db_username" {
  type        = string
  description = "Database user to be used by the glue connection."
  default     = ""
}

variable "db_password" {
  type        = string
  description = "Database paasword to be used by the glue conenction."
  default     = false
}

variable "rds_instance_name" {
  type        = string
  description = "Aurora RDS Database instance name"
  default = ""
}
